## What is GemBox.Document?

GemBox.Document is a .NET component that enables you to read, write, convert, and print document files (DOCX, DOC, PDF, RTF, HTML, and ODT) from .NET applications.

With GemBox.Document you get a fast and reliable component that’s easy to use and doesn't depend on Microsoft Word. It requires only .NET and it’s much faster than Microsoft Office Automation!

## GemBox.Document Features

- [Read](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-open-read-word-file/301) Word (DOCX, DOC), ODT, HTML, RTF, XML (Flat OPC, WordML), TXT, and [PDF](https://www.gemboxsoftware.com/document/examples/c-sharp-read-extract-pdf-tables/305) files.
- [Write / create](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-create-write-word-file/302) and [convert](https://www.gemboxsoftware.com/document/examples/c-sharp-convert-word-to-pdf/304) to DOCX, ODT, PDF, PDF/A, XPS, HTML, RTF, XML (Flat OPC, WordML), TXT, and image formats.
- View and edit documents in [WPF](https://www.gemboxsoftware.com/document/examples/word-xpsdocument-wpf/5201), [ASP.NET](https://www.gemboxsoftware.com/document/examples/word-editor-asp-net-mvc/5102), [ASP.NET Core](https://www.gemboxsoftware.com/document/examples/asp-net-core-create-word-docx-pdf/5601), and [Windows.Forms](https://www.gemboxsoftware.com/document/examples/word-editor-windows-forms/5301) applications.
- [Print](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-print-word/351) documents.
- [Protect](https://www.gemboxsoftware.com/document/examples/docx-write-protection/1101), [encrypt](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-docx-encryption/1102), and [digitally sign](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-pdf-digital-signature/1104) documents.
- Get, create, or edit [paragraphs](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-create-write-word-file/302), [text](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-create-write-word-file/302), [tables](https://www.gemboxsoftware.com/document/examples/word-table/1201), [hyperlinks](https://www.gemboxsoftware.com/document/examples/word-bookmarks-hyperlinks/204), [bookmarks](https://www.gemboxsoftware.com/document/examples/word-bookmarks-hyperlinks/204), [fields](https://www.gemboxsoftware.com/document/examples/word-fields/206), [sections](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-create-write-word-file/302), [headers, footers](https://www.gemboxsoftware.com/document/examples/word-header-footer/208), and [footnotes and endnotes](https://www.gemboxsoftware.com/document/examples/word-footnote-endnote/212).
- Get, create, or edit drawings like [shapes](https://www.gemboxsoftware.com/document/examples/word-shapes/203), [pictures](https://www.gemboxsoftware.com/document/examples/word-pictures/201), [charts](https://www.gemboxsoftware.com/document/examples/word-charts/213), and [text boxes](https://www.gemboxsoftware.com/document/examples/word-textboxes/202).
- Get, create, or edit [paragraph](https://www.gemboxsoftware.com/document/examples/word-paragraph-formatting/602), [character](https://www.gemboxsoftware.com/document/examples/word-character-formatting/601), [list](https://www.gemboxsoftware.com/document/examples/word-lists/603), [table](https://www.gemboxsoftware.com/document/examples/word-table-formatting/1204), [table row](https://www.gemboxsoftware.com/document/examples/word-table-formatting/1204), and [table cell](https://www.gemboxsoftware.com/document/examples/word-table-formatting/1204) formatting.
- Get, create, or edit [paragraph](https://www.gemboxsoftware.com/document/examples/word-styles/604), [list](https://www.gemboxsoftware.com/document/examples/word-lists/603), [character](https://www.gemboxsoftware.com/document/examples/word-styles/604), and [table](https://www.gemboxsoftware.com/document/examples/word-table-styles/1205) styles.
- Access or modify [section properties](https://www.gemboxsoftware.com/document/examples/word-page-setup/209), [picture properties](https://www.gemboxsoftware.com/document/examples/word-pictures/201), [default paragraph, character formatting](https://www.gemboxsoftware.com/document/examples/word-style-resolution/101), and more.
- Get and set [built-in and custom document properties](https://www.gemboxsoftware.com/document/examples/word-properties/211).
- [Clone](https://www.gemboxsoftware.com/document/examples/cloning/501) or [combine](https://www.gemboxsoftware.com/document/examples/combine-word-file-c-sharp-vb-net/502) document elements between documents.
- Replace or [set bookmark content](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-modify-word-bookmarks/102).
- Load [HTML](https://www.gemboxsoftware.com/document/examples/word-editor-asp-net-mvc/5102) / RTF / TXT into a specific document position.
- [Import data to your document](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-mail-merge-word/901) from various data sources and control the document [import region](https://www.gemboxsoftware.com/document/examples/mail-merge-ranges/903) and [import process](https://www.gemboxsoftware.com/document/examples/customize-mail-merge/904).
- [Create](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-create-word-form/701), [read](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-read-word-form/702), or [update](https://www.gemboxsoftware.com/document/examples/c-sharp-vb-net-update-word-form/703) form fields.
[Preserve](https://www.gemboxsoftware.com/document/docs/preservation.html) unsupported document content elements and properties when reading a document. 

## Get Started

You are not sure how to start working with Word documents in .NET using GemBox.Document? Check the code below that shows how to create a DOCX file from scratch and write 'Hello World!' on it.

```csharp
// If using Professional version, put your serial key below.
ComponentInfo.SetLicense("FREE-LIMITED-KEY");

// Create a new empty document.
var document = new DocumentModel();

// Add a section with one paragraph and some text.
document.Sections.Add(
    new Section(document,
        new Paragraph(document, "Hello World!")));

// Save the document as Word's DOCX file.
document.Save("Output.docx");
```

For more GemBox.Document code examples and demos, please visit our [examples page](https://www.gemboxsoftware.com/document/examples/getting-started/801).

## Resources

- [Product Page](https://www.gemboxsoftware.com/document)
- [Examples](https://www.gemboxsoftware.com/document/examples)
- [Documentation](https://www.gemboxsoftware.com/document/docs/introduction.html)
- [API Reference](https://www.gemboxsoftware.com/document/docs/GemBox.Document.html)
- [Forum](https://forum.gemboxsoftware.com/c/gembox-document/6)
- [Blog](https://www.gemboxsoftware.com/gembox-document)
